@@ -10,7 +10,7 @@
 #define OKTETA_ABSTRACTBYTEARRAYVIEW_HPP
 
 // lib
-#include <okteta/columnsview.hpp>
+#include "columnsview.hpp"
 // Okteta core
 #include <Okteta/AddressRange>
 // Qt
@@ -48,6 +48,7 @@ class OKTETAGUI_EXPORT AbstractByteArrayView : public ColumnsView
     friend class MouseNavigator;
     friend class MousePaster;
     friend class Dragger;
+    friend class TapNavigator;
 
     Q_OBJECT
     Q_PROPERTY(bool OverwriteMode READ isOverwriteMode WRITE setOverwriteMode NOTIFY overwriteModeChanged)
@@ -127,10 +128,9 @@ public:
     Q_ENUM(CodingTypes)
 
 protected:
-    AbstractByteArrayView(AbstractByteArrayViewPrivate* d, QWidget* parent);
+    OKTETAGUI_NO_EXPORT AbstractByteArrayView(AbstractByteArrayViewPrivate* d, QWidget* parent);
 
 public:
-    AbstractByteArrayView() = delete;
     ~AbstractByteArrayView() override;
 
 public: // value access
@@ -176,7 +176,14 @@ public: // value access
      */
     const QString& charCodingName() const;
 
+public: // zooming values
+    // TODO: on next ABI change, rename to zoomScale
     double zoomLevel() const;
+    inline double zoomScale() const { return zoomLevel(); }
+    int zoomInLevelsSize() const;
+    int zoomOutLevelsSize() const;
+    double zoomScaleForLevel(int zoomLevel) const;
+    int zoomLevelForScale(double zoomScale) const;
 
 public: // value access API
     // value column
@@ -277,7 +284,7 @@ public:
 
     /** sets the number of bytes per line, switching the resize style to Okteta::FixedLayoutStyle */
     void setNoOfBytesPerLine(int noOfBytesPerLine);
-    /** sets absolut offset of the data */
+    /** sets absolute offset of the data */
     void setStartOffset(Address startOffset);
     /** sets offset of the char in the upper left corner */
     void setFirstLineOffset(Address firstLineOffset);
@@ -350,7 +357,9 @@ public: // zooming
     void zoomOut();
     void zoomTo(int pointSize);
     void unZoom();
-    void setZoomLevel(double level);
+    // TODO: on next ABI change, renamve to setZoomScale
+    void setZoomLevel(double zoomScale);
+    inline void setZoomScale(double zoomScale) { setZoomLevel(zoomScale); }
 
 public: // cursor control
     /** we have focus again, start the timer */
@@ -385,7 +394,7 @@ public: // logic value service
 Q_SIGNALS:
     /** Index of the byte that was clicked */
     void clicked(Okteta::Address index);
-    /** Index of the byte that was double clicked */
+    /** Index of the byte that was double-clicked */
     void doubleClicked(Okteta::Address index);
 
     void cursorPositionChanged(Okteta::Address index);
@@ -416,7 +425,9 @@ Q_SIGNALS:
     void undefinedCharChanged(QChar undefinedChar);
     void noOfGroupedBytesChanged(int noOfGroupedBytes);
 
-    void zoomLevelChanged(double level);
+    // TODO: on next ABI change, rename to zoomScaleChanged
+    void zoomLevelChanged(double zoomScale);
+    void zoomLevelsChanged();
 
 protected:
     void finishByteEdit();
@@ -449,6 +460,7 @@ protected: // QWidget API
     void dragLeaveEvent(QDragLeaveEvent* dragLeaveEvent) override;
     void dropEvent(QDropEvent* dropEvent) override;
     void contextMenuEvent(QContextMenuEvent* contextMenuEvent) override;
+    void timerEvent(QTimerEvent* timerEvent) override;
 
 protected: // QAbstractScrollArea API
     void wheelEvent(QWheelEvent* e) override;
